@@ -1,3 +1,6 @@
 from .device import (ColorSensor, GyroSensor, Hub, Motor, SonarSensor,  # noqa
                      TouchSensor)
 from .etrobo import ETRobo  # noqa
+
+__author__ = 'Atsushi TAKEDA'
+__version__ = '0.2'
